==> discord.js-basic-3.4.9.tgz: package/index.js <==
const { MessageEmbed, MessageActionRow, MessageButton, Client, MessageSelectMenu, Modal, TextInputComponent } = require('discord.js');



// Discord Client 
class $client extends Client {

  constructor(data) {

    super(data);

  }

  

}
// Discord Client End

// Discord Message Event
const { Message } = require('discord.js');

class $message extends Message {

  constructor(data, client) {

    super(client, data, null);

  }
}
  async function $sendMessage(text, channel, ...row) {
if(row) {
    const message = await channel.send({content: text, components: [...row] });

    return message;

  } else {
   const message = await channel.send({content: text });   
   return message;
  }
      }
//Discord Message Event End

// Client Events
function $event(client, eventName, eventFunction) {
  if (!(client instanceof Client)) {
    throw new TypeError('client must be a Client object.');
  }

  if (typeof eventName !== 'string') {
    throw new TypeError('eventName must be a string.');
  }

  if (typeof eventFunction !== 'function') {
    throw new TypeError('eventFunction must be a function.');
  }

  client.on(eventName, eventFunction);
}
// Client Events End


// Embed Builder Function
class $embed {
  constructor(channel) {
    this.channel = channel;
      
    this.embed = new MessageEmbed();
    
  }

    
  title(title) {
    this.embed.setTitle(title);
    return this;
  }

  description(description) {
    this.embed.setDescription(description);
    return this;
  }

  URL(url) {
    this.embed.setURL(url);
    return this;
  }

  color(color) {
    this.embed.setColor(color);
    return this;
  }

  author(name, iconURL, url) {
    this.embed.setAuthor(name, iconURL, url);
    return this;
  }

  thumbnail(url) {
    this.embed.setThumbnail(url);
    return this;
  }

  field(name, value, inline = false) {
    this.embed.addField(name, value, inline);
    return this;
  }

  fields(...fields) {
    this.embed.addFields(...fields);
    return this;
  }

  image(url) {
    this.embed.setImage(url);
    return this;
  }

  footer(text, iconURL) {
    this.embed.setFooter(text, iconURL);
    return this;
  }

  timestamp(timestamp = Date.now()) {
    this.embed.setTimestamp(timestamp);
    return this;
  }
    

  send(text, ...row) {
      if(text) {
        if(row) {
    this.channel.send({ embeds: [this.embed], content: text, components: [...row] });
            } else {
          this.channel.send({ embeds: [this.embed], content: text });      
            }
          } else {
              if(row) {
          this.channel.send({ embeds: [this.embed], components: [...row] });    
              } else {
          this.channel.send({ embeds: [this.embed] });        
              }
          }
  }
    
 sendWithRow(...buttons) {
this.channel.send({ embeds: [this.embed], components: [new MessageActionRow().addComponents(...buttons)]})
    
     }
     save() {
       const embed = this.embed
       return embed
     }
  }   
 // Embed Builder Function End  
    
    







 









// Button Builder Function
class $button {
  constructor() {
      
   this.button = new MessageButton();
      
  }
customId(id) {

    this.button.setCustomId(id);
return this
  }

  label(label) {

    this.button.setLabel(label);
return this
  }

  style(style) {

    this.button.setStyle(style);
return this
  }

  disabled(disabled) {

  this.button.setDisabled(disabled);
return this
  }

  emoji(emoji) {

    this.button.setEmoji(emoji);
return this
  }

  url(url) {

  this.button.setURL(url);
return this
  }
  
save() {
    const buton = this.button
    return buton
}
  
}
// Button Builder Function End





  

  

  
  
// Select Menu Builder Function
class $selectMenu {
  constructor() {
    this.menu = new MessageSelectMenu();
  }

  customId(customId) {
    this.menu.setCustomId(customId);
    return this;
  }

placeholder(label) {

    this.menu.setPlaceholder(label)

    return this;

  }
 
options(...options) {

    this.menu.addOptions([...options]);

    return this;

  }
  
  minValues(numher) {

    this.menu.setMinValues(number);

    return this;

  }
  
 maxValues(numher) {

    this.menu.setMaxValues(number);

    return this;

  }   
  
    
    save() {
        const menu = this.menu
        return menu;
    }
    
}
// Select Menu Builder Function
 

// Slash Command Builder Function
const { SlashCommandBuilder } = require('@discordjs/builders');

class $slashCommand {
    constructor() {

    this.slash = new SlashCommandBuilder();

  }
  name(name) {
     this.slash.setName(name);
      return this;
  }

  description(description) {
     this.slash.setDescription(description);
      return this;
  }

  stringOption(name, description, required = false) {
   this.slash.addStringOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  integerOption(name, description, required = false) {
    this.slash.addIntegerOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  booleanOption(name, description, required = false) {
  this.slash.addBooleanOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  userOption(name, description, required = false) {
   this.slash.addUserOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  channelOption(name, description, required = false) {
    this.slash.addChannelOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  roleOption(name, description, required = false) {
   this.slash.addRoleOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  mentionableOption(name, description, required = false) {
    this.slash.addMentionableOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  subcommand(subcommand) {
   this.slash.addSubcommand(subcommand);
      return this;
  }

  subcommandGroup(subcommandGroup) {
    this.slash.addSubcommandGroup(subcommandGroup);
      return this;
  }
    
  toJSON() {

    return this.slash.toJSON();

  }
    type(type) {

    this.slash.setType(type);

    return this;

  }
    
}
// Slash Command Builder End

// Modal Builder
class $modal {
   constructor(interaction) {
       this.interaction = interaction
       this.modal = new Modal();
       
   }
  title(title) {
     this.modal.setTitle(title)
      return this;
  }  
customId(id) {

     this.modal.setCustomId(id)

      return this;

  }    
  
    components(...interactions) {

     this.modal.addComponents(...interactions)

      return this;

  }    
 async save() {
return this.modal 
    }   
}

class $textComponent {
    constructor() {
       this.textComponent = new TextInputComponent(); 
    }
   label(label) {
       this.textComponent.setLabel(label)
       return this
   } 
  style(stil) {

       this.textComponent.setStyle(stil)
      return this

   } 
    placeholder(label) {
        this.textComponent.setPlaceholder(label)
        return this
    }
    customId(id) {

        this.textComponent.setCustomId(id)

        return this

    }
    required(secim) {
        this.textComponent.setRequired(secim)
        return this
    }
    minCharacters(length) {

        this.textComponent.setMinLength(length)

        return this

    }
    maxCharacters(length) {

        this.textComponent.setMaxLength(length)

        return this

    }
    save() {

        const TextComponent = this.textComponent

        return TextComponent;

    }
}
  // Modal Builder End
  
  // ShowModal 
  class $showModal {
    constructor(interaction) {
      this.interaction = interaction
      
    }
 
 save(modal) {
   if(this.interaction.isModalSubmit) return null;
    return this.interaction.showModal(modal)
  }
  }

// MessageActionRow Builder
class $row {
    constructor(...interactions) {
        this.row = new MessageActionRow().addComponents(...interactions)
    }
  save() {
      return this.row
  }  
}
// MessageActionRow Builder End





    

    

// Message Reply Function
async function $reply(seçim, diğerolay) {
    
    const reply = seçim.reply(diğerolay)
}
// Message Reply Function End

// İnteraction Get Function





  async function $interactionEvent(client, eventFunction) {
    if(!(client instanceof Client)) {
    throw new TypeError('client must be a Client object.');
  }
   
 client.on("interactionCreate", eventFunction)
 
 }   
// İnteraction Get Function End

// Timed Message Function 
async function $timedMessage(time, channel, diğerolay) {
  
  const message = await channel.send(diğerolay).then(async (msg) => {
    setTimeout(async () => {
      msg.delete().catch()
    }, time)
  })

    return message;
}
// Timed Message Function End

// Pull Interactions 
// Pull Button
async function $getButton(interaction, id) {

  if(interaction.isButton()) {
    
    if (interaction.customId === id) {
      return interaction.component;
    }
  }
  
  return null;
}
// Pull Button End

// Pull Select Menu
async function $getMenu(interaction, id) {
if(interaction.isCommand()) return null;
if(interaction.isModalSubmit()) return null;
  if (interaction.isSelectMenu()) {
    
    if (interaction.customId === id) {
      return interaction.component;
    }
  }
  
  return null;
}
// Pull Select Menu End

// Pull Modal
async function $getModal(interaction, id) {
if(interaction.isCommand()) return null;

  if(interaction.isModalSubmit()) {
    
    if (interaction.customId === id) {
      return interaction.component;
    }
  }
  
  return null;
}
// Pull Modal End

// Pull TextComponent
async function $getTextComponent(interaction, id) {
  if(interaction.isModalSubmit()) {
  const text = interaction.fields.getTextInputValue(id)
    
  return text
  }
}
// Pull TextComponent End
// Pull Interactions End

// Roles
async function $addRole(member, role) {
  member.roles.add(role)
}
async function $removeRole(member, role) {
  member.roles.remove(role)
}
// Roles End

// Reactions 
async function $addReaction(message, emoji) {
  message.react(emoji)
  } 
async function $removeReaction(message, emoji) {
message.reactions.cache.get(emoji).remove()
	.catch(error => console.error('Failed to remove reactions:', error));
  } 
  // Reactions End
  
  // Get Mentions
  function $getMentionedMember(message) {
  const member = message.mentions.members.first();
  return member ? member : null;
}
function $getMentionedChannel(message) {
  const channel = message.mentions.channels.first();
  return channel ? channel : null;
  }
function $getMentionedRole(message) {
  const role = message.mentions.roles.first();
  return role ? role : null;
}
  // Get Mentions End
  
  // Get İnfos
  function $getUser(client, input) {
return client.users.cache.get(input)
        }
function $getChannel(client, input) {
return client.channels.cache.get(input)
}
function $getGuild(client, input) {
return client.guild.cache.get(input)
} 
// Get İnfos End

// Channel Functions
async function $createChannel(guild, channelName, channelType, options) {
  try {
    const channel = await guild.channels.create(channelName, {
      type: channelType,
      ...options
    });
    
    return channel;
  } catch (error) {
    console.error(`Failed to create channel: ${error}`);
  }
}

async function $deleteChannel(kanal) {
  try {
    const channel = await kanal.delete()
    
    return channel;
  } catch (error) {
    console.error(`Failed to delete channel: ${error}`);
  }
      }
      // Channel Functions End
module.exports = { $message, $embed, $client, $sendMessage, $event, $button, $selectMenu, $slashCommand, $modal, $row, $textComponent, $reply, $interactionEvent, $timedMessage, $getButton, $getMenu, $getModal, $getTextComponent, $removeRole, $addRole, $addReaction, $removeReaction, $getMentionedMember, $getMentionedChannel, $getMentionedRole, $getUser, $getChannel, $getGuild, $createChannel, $deleteChannel, $showModal }

==> discord.js-basic-3.5.0.tgz: package/index.js <==
const { MessageEmbed, MessageActionRow, MessageButton, Client, MessageSelectMenu, Modal, TextInputComponent } = require('discord.js');



// Discord Client 
class $client extends Client {

  constructor(data) {

    super(data);

  }

  

}
// Discord Client End

// Discord Message Event
const { Message } = require('discord.js');

class $message extends Message {

  constructor(data, client) {

    super(client, data, null);

  }
}
  async function $sendMessage(text, channel, ...row) {
if(row) {
    const message = await channel.send({content: text, components: [...row] });

    return message;

  } else {
   const message = await channel.send({content: text });   
   return message;
  }
      }
//Discord Message Event End

// Client Events
function $event(client, eventName, eventFunction) {
  if (!(client instanceof Client)) {
    throw new TypeError('client must be a Client object.');
  }

  if (typeof eventName !== 'string') {
    throw new TypeError('eventName must be a string.');
  }

  if (typeof eventFunction !== 'function') {
    throw new TypeError('eventFunction must be a function.');
  }

  client.on(eventName, eventFunction);
}
// Client Events End


// Embed Builder Function
class $embed {
  constructor(channel) {
    this.channel = channel;
      
    this.embed = new MessageEmbed();
    
  }

    
  title(title) {
    this.embed.setTitle(title);
    return this;
  }

  description(description) {
    this.embed.setDescription(description);
    return this;
  }

  URL(url) {
    this.embed.setURL(url);
    return this;
  }

  color(color) {
    this.embed.setColor(color);
    return this;
  }

  author(name, iconURL, url) {
    this.embed.setAuthor(name, iconURL, url);
    return this;
  }

  thumbnail(url) {
    this.embed.setThumbnail(url);
    return this;
  }

  field(name, value, inline = false) {
    this.embed.addField(name, value, inline);
    return this;
  }

  fields(...fields) {
    this.embed.addFields(...fields);
    return this;
  }

  image(url) {
    this.embed.setImage(url);
    return this;
  }

  footer(text, iconURL) {
    this.embed.setFooter(text, iconURL);
    return this;
  }

  timestamp(timestamp = Date.now()) {
    this.embed.setTimestamp(timestamp);
    return this;
  }
    

  send(text, ...row) {
      if(text) {
        if(row) {
    this.channel.send({ embeds: [this.embed], content: text, components: [...row] });
            } else {
          this.channel.send({ embeds: [this.embed], content: text });      
            }
          } else {
              if(row) {
          this.channel.send({ embeds: [this.embed], components: [...row] });    
              } else {
          this.channel.send({ embeds: [this.embed] });        
              }
          }
  }
    
 sendWithRow(...buttons) {
this.channel.send({ embeds: [this.embed], components: [new MessageActionRow().addComponents(...buttons)]})
    
     }
     save() {
       const embed = this.embed
       return embed
     }
  }   
 // Embed Builder Function End  
    
    







 









// Button Builder Function
class $button {
  constructor() {
      
   this.button = new MessageButton();
      
  }
customId(id) {

    this.button.setCustomId(id);
return this
  }

  label(label) {

    this.button.setLabel(label);
return this
  }

  style(style) {

    this.button.setStyle(style);
return this
  }

  disabled(disabled) {

  this.button.setDisabled(disabled);
return this
  }

  emoji(emoji) {

    this.button.setEmoji(emoji);
return this
  }

  url(url) {

  this.button.setURL(url);
return this
  }
  
save() {
    const buton = this.button
    return buton
}
  
}
// Button Builder Function End





  

  

  
  
// Select Menu Builder Function
class $selectMenu {
  constructor() {
    this.menu = new MessageSelectMenu();
  }

  customId(customId) {
    this.menu.setCustomId(customId);
    return this;
  }

placeholder(label) {

    this.menu.setPlaceholder(label)

    return this;

  }
 
options(...options) {

    this.menu.addOptions([...options]);

    return this;

  }
  
  minValues(numher) {

    this.menu.setMinValues(number);

    return this;

  }
  
 maxValues(numher) {

    this.menu.setMaxValues(number);

    return this;

  }   
  
    
    save() {
        const menu = this.menu
        return menu;
    }
    
}
// Select Menu Builder Function
 

// Slash Command Builder Function
const { SlashCommandBuilder } = require('@discordjs/builders');

class $slashCommand {
    constructor() {

    this.slash = new SlashCommandBuilder();

  }
  name(name) {
     this.slash.setName(name);
      return this;
  }

  description(description) {
     this.slash.setDescription(description);
      return this;
  }

  stringOption(name, description, required = false) {
   this.slash.addStringOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  integerOption(name, description, required = false) {
    this.slash.addIntegerOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  booleanOption(name, description, required = false) {
  this.slash.addBooleanOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  userOption(name, description, required = false) {
   this.slash.addUserOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  channelOption(name, description, required = false) {
    this.slash.addChannelOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  roleOption(name, description, required = false) {
   this.slash.addRoleOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  mentionableOption(name, description, required = false) {
    this.slash.addMentionableOption(option => option.setName(name).setDescription(description).setRequired(required));
      return this;
  }

  subcommand(subcommand) {
   this.slash.addSubcommand(subcommand);
      return this;
  }

  subcommandGroup(subcommandGroup) {
    this.slash.addSubcommandGroup(subcommandGroup);
      return this;
  }
    
  toJSON() {

    return this.slash.toJSON();

  }
    type(type) {

    this.slash.setType(type);

    return this;

  }
    
}
// Slash Command Builder End

// Modal Builder
class $modal {
   constructor(interaction) {
       this.interaction = interaction
       this.modal = new Modal();
       
   }
  title(title) {
     this.modal.setTitle(title)
      return this;
  }  
customId(id) {

     this.modal.setCustomId(id)

      return this;

  }    
  
    components(...interactions) {

     this.modal.addComponents(...interactions)

      return this;

  }    
 async save() {
return this.modal 
    }   
}

class $textComponent {
    constructor() {
       this.textComponent = new TextInputComponent(); 
    }
   label(label) {
       this.textComponent.setLabel(label)
       return this
   } 
  style(stil) {

       this.textComponent.setStyle(stil)
      return this

   } 
    placeholder(label) {
        this.textComponent.setPlaceholder(label)
        return this
    }
    customId(id) {

        this.textComponent.setCustomId(id)

        return this

    }
    required(secim) {
        this.textComponent.setRequired(secim)
        return this
    }
    minCharacters(length) {

        this.textComponent.setMinLength(length)

        return this

    }
    maxCharacters(length) {

        this.textComponent.setMaxLength(length)

        return this

    }
    save() {

        const TextComponent = this.textComponent

        return TextComponent;

    }
}
  // Modal Builder End
  
  // ShowModal 
  async function $showModal(interaction, modal) {
    if(modal) {
      if(interaction.isButton() || interaction.isSelectMenu() || interaction.isCommand()) {
        const form = interaction.showModal(modal)
        return form
      }
    }
  }

// MessageActionRow Builder
class $row {
    constructor(...interactions) {
        this.row = new MessageActionRow().addComponents(...interactions)
    }
  save() {
      return this.row
  }  
}
// MessageActionRow Builder End





    

    

// Message Reply Function
async function $reply(seçim, diğerolay) {
    
    const reply = seçim.reply(diğerolay)
}
// Message Reply Function End

// İnteraction Get Function





  async function $interactionEvent(client, eventFunction) {
    if(!(client instanceof Client)) {
    throw new TypeError('client must be a Client object.');
  }
   
 client.on("interactionCreate", eventFunction)
 
 }   
// İnteraction Get Function End

// Timed Message Function 
async function $timedMessage(time, channel, diğerolay) {
  
  const message = await channel.send(diğerolay).then(async (msg) => {
    setTimeout(async () => {
      msg.delete().catch()
    }, time)
  })

    return message;
}
// Timed Message Function End

// Pull Interactions 
// Pull Button
async function $getButton(interaction, id) {

  if(interaction.isButton()) {
    
    if (interaction.customId === id) {
      return interaction.component;
    }
  }
  
  return null;
}
// Pull Button End

// Pull Select Menu
async function $getMenu(interaction, id) {
if(interaction.isCommand()) return null;
if(interaction.isModalSubmit()) return null;
  if (interaction.isSelectMenu()) {
    
    if (interaction.customId === id) {
      return interaction.component;
    }
  }
  
  return null;
}
// Pull Select Menu End

// Pull Modal
async function $getModal(interaction, id) {
if(interaction.isCommand()) return null;

  if(interaction.isModalSubmit()) {
    
    if (interaction.customId === id) {
      return interaction.component;
    }
  }
  
  return null;
}
// Pull Modal End

// Pull TextComponent
async function $getTextComponent(interaction, id) {
  if(interaction.isModalSubmit()) {
  const text = interaction.fields.getTextInputValue(id)
    
  return text
  }
}
// Pull TextComponent End
// Pull Interactions End

// Roles
async function $addRole(member, role) {
  member.roles.add(role)
}
async function $removeRole(member, role) {
  member.roles.remove(role)
}
// Roles End

// Reactions 
async function $addReaction(message, emoji) {
  message.react(emoji)
  } 
async function $removeReaction(message, emoji) {
message.reactions.cache.get(emoji).remove()
	.catch(error => console.error('Failed to remove reactions:', error));
  } 
  // Reactions End
  
  // Get Mentions
  function $getMentionedMember(message) {
  const member = message.mentions.members.first();
  return member ? member : null;
}
function $getMentionedChannel(message) {
  const channel = message.mentions.channels.first();
  return channel ? channel : null;
  }
function $getMentionedRole(message) {
  const role = message.mentions.roles.first();
  return role ? role : null;
}
  // Get Mentions End
  
  // Get İnfos
  function $getUser(client, input) {
return client.users.cache.get(input)
        }
function $getChannel(client, input) {
return client.channels.cache.get(input)
}
function $getGuild(client, input) {
return client.guild.cache.get(input)
} 
// Get İnfos End

// Channel Functions
async function $createChannel(guild, channelName, channelType, options) {
  try {
    const channel = await guild.channels.create(channelName, {
      type: channelType,
      ...options
    });
    
    return channel;
  } catch (error) {
    console.error(`Failed to create channel: ${error}`);
  }
}

async function $deleteChannel(kanal) {
  try {
    const channel = await kanal.delete()
    
    return channel;
  } catch (error) {
    console.error(`Failed to delete channel: ${error}`);
  }
      }
      // Channel Functions End
module.exports = { $message, $embed, $client, $sendMessage, $event, $button, $selectMenu, $slashCommand, $modal, $row, $textComponent, $reply, $interactionEvent, $timedMessage, $getButton, $getMenu, $getModal, $getTextComponent, $removeRole, $addRole, $addReaction, $removeReaction, $getMentionedMember, $getMentionedChannel, $getMentionedRole, $getUser, $getChannel, $getGuild, $createChannel, $deleteChannel, $showModal }
